Learn R Programming

Rsearch (version 1.0.0)

Rsearch-package: Rsearch

Description

An R package designed for handling and analyzing targeted sequencing data. Many of its functions are based on the command-line based tool VSEARCH. By integrating VSEARCH into an R package, Rsearch provides significant utility by making the software more accessible to a broad user base, particularly those who prefer or require an R-based workflow. In addition to the VSEARCH-based functions, Rsearch includes additional tools to aid in microbiome data analysis, such as data processing functions and visualizations of some of the results from the functions.

Arguments

Author

Maintainer: Cassandra Stamsaas cassandra.hjortdahl@nmbu.no

Authors:

See Also