Learn R Programming

Rsearch (version 1.0.0)

phyloseq2rsearch: Convert phyloseq object to Rsearch object

Description

Creating an Rsearch object (list) from a phyloseq object.

Usage

phyloseq2rsearch(phyloseq.obj)

Value

A list with entries as in a Rsearch object, except that the sequence.tbl do not contain sequences, only taxonomy.

Arguments

phyloseq.obj

(Required). A phyloseq object, see phyloseq.

Details

This function converts a phyloseq object to a simple list with three elements as dataframes (or tibbles). The entries are named according to the structure used in rsearch_obj

References

https://joey711.github.io/phyloseq/

See Also

rsearch_obj

Examples

Run this code
if (FALSE) {
# Convert phyloseq object to Rsearch object
rsearch_obj <- phyloseq2rsearch(phy_obj)

# Extract read count data
rsearch_obj$readcount.mat

# Extract sample data
rsearch_obj$sampledata.df

# Extract sequence data
rsearch_obj$sequence.df
}

Run the code above in your browser using DataLab