- fastq_input
(Required). A FASTQ file path, FASTQ tibble (forward
reads), or a paired-end tibble of class "pe_df". See Details.
- reverse
(Optional). A FASTQ file path or FASTQ tibble (reverse reads).
Optional if fastq_input is a "pe_df" object.
- minovlen
(Optional). Minimum overlap between the merged reads. Must be
at least 5. Defaults to 10.
- truncee_rate_range
(Optional). A numeric vector of truncee_rate
values to test. Sequences are truncated so that their average expected error
per base is lower than the specified value. Defaults to (0.002, 0.004,
0.006, 0.008, 0.010, 0.012, 0.014, 0.016, 0.018, 0.020, 0.022, 0.024, 0.026,
0.028, 0.030, 0.032, 0.034, 0.036, 0.038, 0.040).
- minlen
(Optional). Minimum number of bases a sequence must have to be
retained. Defaults to 0. See Details.
- min_size
(Optional). Minimum copy number (size) for a merged read to
be included in the results. Defaults to 2.
- maxee_rate
(Optional). Threshold for average expected error. Must
range from 0.0 to 1.0. Defaults to 0.01. See
Details.
- threads
(Optional). Number of computational threads to be used by
VSEARCH. Defaults to 1.
- plot_title
(Optional). If TRUE (default), a summary title will
be displayed in the plot. Set to FALSE for no title.
- tmpdir
(Optional). Path to the directory where temporary files should
be written when tables are used as input or output. Defaults to
NULL, which resolves to the session-specific temporary directory
(tempdir()).