powered by
rsearch2phyloseq converts an Rsearch object to a phyloseq object.
rsearch2phyloseq
rsearch2phyloseq(rsearch.obj, sample_id_col = "sample_id")
A phyloseq object.
phyloseq
(Required). An Rsearch object, see rsearch_obj.
rsearch_obj
(Optional). A character string specifying the name of the column in sampledata.df that contains sample identifiers. Defaults to "sample_id".
sampledata.df
"sample_id"
This function converts an Rsearch object, which is a simple list, to a phyloseq object from the phyloseq R package.
list
https://joey711.github.io/phyloseq/
if (FALSE) { # Convert Rsearch object to phyloseq object phy_obj <- rsearch2phyloseq(obj, sample_id_col = "sample_id") }
Run the code above in your browser using DataLab