Read pairs from the input FASTQ files (fastq_input and reverse)
are joined into a single sequence by adding a gap with a specified padding
sequence. The resulting sequences consist of the forward read, the padding
sequence, and the reverse complement of the reverse read.
fastq_input and reverse can either be file paths to FASTQ files
or FASTQ objects. FASTQ objects are tibbles that contain the columns
Header, Sequence, and Quality, see
readFastq. Forward and reverse reads must appear in the same
order and have the same total number of reads in both files.
If fastq_input is an object of class "pe_df", the reverse reads
are automatically extracted from its "reverse" attribute unless
explicitly provided via the reverse argument. This simplifies function
calls when using paired-end tibbles created by functions such as
fastx_synchronize or vs_fastx_trim_filt.
If fastaout or fastqout is specified, the joined reads are
written to the respective file in either FASTA or FASTQ format.
If both fastaout or fastqout are NULL, the results are
returned as a FASTA or FASTQ object, and no file is written.
output_format must match the desired output files/objects.
Any input sequence with fewer bases than the value set in minlen is
discarded. By default, minlen is set to 0, which means that no
sequences are removed. However, using the default value may allow empty
sequences to remain in the results.
vsearch_options allows users to pass additional command-line arguments
to VSEARCH that are not directly supported by this function. Refer to
the VSEARCH manual for more details.